@@ -46,5 +46,5 @@ p <- plotDiffTpcaVolcano(diff_tpca)
 
 expect_equal(
     class(p),
-    c("gg", "ggplot")
+    c("ggplot2::ggplot", "ggplot", "ggplot2::gg", "S7_object", "gg")
 )
